@@ -53,7 +53,7 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
+        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -387,61 +387,6 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>MenuWorker</name>
-    <message>
-        <source>Fashion Mode</source>
-        <translation>Fashion-tilstand</translation>
-    </message>
-    <message>
-        <source>Efficient Mode</source>
-        <translation>Effektiv tilstand</translation>
-    </message>
-    <message>
-        <source>Top</source>
-        <translation>Øverst</translation>
-    </message>
-    <message>
-        <source>Bottom</source>
-        <translation>Nederst</translation>
-    </message>
-    <message>
-        <source>Left</source>
-        <translation>Venstre</translation>
-    </message>
-    <message>
-        <source>Right</source>
-        <translation>Højre</translation>
-    </message>
-    <message>
-        <source>Keep Shown</source>
-        <translation>Hold vist</translation>
-    </message>
-    <message>
-        <source>Keep Hidden</source>
-        <translation>Hold skjult</translation>
-    </message>
-    <message>
-        <source>Smart Hide</source>
-        <translation>Smart skjul</translation>
-    </message>
-    <message>
-        <source>Mode</source>
-        <translation>Tilstand</translation>
-    </message>
-    <message>
-        <source>Location</source>
-        <translation>Placering</translation>
-    </message>
-    <message>
-        <source>Status</source>
-        <translation>Status</translation>
-    </message>
-    <message>
-        <source>Dock settings</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>NotificationPlugin</name>
     <message>
