@@ -51,7 +51,7 @@
         <translation>Disattivato</translation>
     </message>
     <message>
-        <source>Disable Airplane Mode first if you want to connect to a Bluetooth</source>
+        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
         <translation type="unfinished"/>
     </message>
 </context>
@@ -385,61 +385,6 @@
         <translation type="unfinished"/>
     </message>
 </context>
-<context>
-    <name>MenuWorker</name>
-    <message>
-        <source>Fashion Mode</source>
-        <translation>Fashion</translation>
-    </message>
-    <message>
-        <source>Efficient Mode</source>
-        <translation>Efficient</translation>
-    </message>
-    <message>
-        <source>Top</source>
-        <translation>Sopra</translation>
-    </message>
-    <message>
-        <source>Bottom</source>
-        <translation>Sotto</translation>
-    </message>
-    <message>
-        <source>Left</source>
-        <translation>Sinistra</translation>
-    </message>
-    <message>
-        <source>Right</source>
-        <translation>Destra</translation>
-    </message>
-    <message>
-        <source>Keep Shown</source>
-        <translation>Mostra sempre</translation>
-    </message>
-    <message>
-        <source>Keep Hidden</source>
-        <translation>Lascia nascosta</translation>
-    </message>
-    <message>
-        <source>Smart Hide</source>
-        <translation>Nascondi automaticamente</translation>
-    </message>
-    <message>
-        <source>Mode</source>
-        <translation>Modalità</translation>
-    </message>
-    <message>
-        <source>Location</source>
-        <translation>Posizione</translation>
-    </message>
-    <message>
-        <source>Status</source>
-        <translation>Comportamento</translation>
-    </message>
-    <message>
-        <source>Dock settings</source>
-        <translation>Impostazioni Dock</translation>
-    </message>
-</context>
 <context>
     <name>NotificationPlugin</name>
     <message>
