@@ -16,7 +16,6 @@
 #include <QToolTip>
 
 #include <DGuiApplicationHelper>
-#include <qglobal.h>
 
 DGUI_USE_NAMESPACE
 
@@ -64,10 +63,9 @@ private:
 }
 
 namespace dock {
-WidgetPlugin::WidgetPlugin(PluginsItemInterface* pluginsItemInterface, QObject *pluginInstance)
-    : QObject()
+WidgetPlugin::WidgetPlugin(PluginsItemInterface* pluginsItemInterface, QObject *parent)
+    : QObject(parent)
     , m_pluginsItemInterface(pluginsItemInterface)
-    , m_pluginInstance(pluginInstance)
 {
     QMetaObject::invokeMethod(this, [this](){
         m_pluginsItemInterface->init(this);
@@ -189,6 +187,7 @@ void WidgetPlugin::itemUpdate(PluginsItemInterface * const itemInter, const QStr
     if (tipsWidget) tipsWidget->update();
 
 }
+
 void WidgetPlugin::itemRemoved(PluginsItemInterface * const itemInter, const QString &itemKey)
 {
     auto widget = m_pluginsItemInterface->itemWidget(itemKey);
@@ -222,9 +221,9 @@ void WidgetPlugin::requestSetAppletVisible(PluginsItemInterface * const itemInte
 
     if (!visible) {
         if (appletWidget == nullptr || !appletWidget->isVisible()) {
-            auto window = itemInter->itemWidget(itemKey)->window();
-            if (window != nullptr) {
-                Plugin::EmbedPlugin *plugin = Plugin::EmbedPlugin::get(window->windowHandle());
+            auto widget = itemInter->itemWidget(itemKey);
+            if (widget && widget->window()) {
+                Plugin::EmbedPlugin *plugin = Plugin::EmbedPlugin::get(widget->window()->windowHandle());
                 if (plugin) {
                     qDebug() << "send hide quick panel message";
                     emit plugin->closeQuickPanel();
@@ -296,6 +295,11 @@ void WidgetPlugin::updateDockContainerState(PluginsItemInterface *itemInter, boo
     iter->message(msg.toJson());
 }
 
+void WidgetPlugin::onDockColorThemeChanged(uint32_t type)
+{
+    DGuiApplicationHelper::instance()->setPaletteType(static_cast<DGuiApplicationHelper::ColorType>(type));
+}
+
 void WidgetPlugin::onDockPositionChanged(uint32_t position)
 {
     qApp->setProperty(PROP_POSITION, position);
@@ -328,10 +332,7 @@ void WidgetPlugin::initConnections(Plugin::EmbedPlugin *plugin, PluginItem *plug
     if (!plugin)
         return;
 
-    connect(plugin, &Plugin::EmbedPlugin::dockColorThemeChanged, this, [](uint32_t type){
-        DGuiApplicationHelper::instance()->setPaletteType(static_cast<DGuiApplicationHelper::ColorType>(type));
-    }, Qt::UniqueConnection);
-
+    connect(plugin, &Plugin::EmbedPlugin::dockColorThemeChanged, this, &WidgetPlugin::onDockColorThemeChanged, Qt::UniqueConnection);
     connect(plugin, &Plugin::EmbedPlugin::dockPositionChanged, this, &WidgetPlugin::onDockPositionChanged, Qt::UniqueConnection);
     connect(plugin, &Plugin::EmbedPlugin::eventMessage, this, &WidgetPlugin::onDockEventMessageArrived, Qt::UniqueConnection);
 
@@ -353,29 +354,30 @@ void WidgetPlugin::initConnections(Plugin::EmbedPlugin *plugin, PluginItem *plug
     });
 
     connect(pluginItem, &PluginItem::recvMouseEvent, plugin, &Plugin::EmbedPlugin::pluginRecvMouseEvent);
+    connect(pluginItem, &PluginItem::sigRequestShutdown, plugin, &Plugin::EmbedPlugin::pluginRequestShutdown);
 }
 
 int WidgetPlugin::getPluginFlags()
 {
-    const Dock::PluginFlags defaultPluginFlags = Dock::PluginFlag::Type_Tray | Dock::PluginFlag::Attribute_Normal;
+    Dock::PluginFlags flags = Dock::PluginFlag::Type_Tray | Dock::PluginFlag::Attribute_Normal;
 
     auto pluginsItemInterfaceV2 = dynamic_cast<PluginsItemInterfaceV2 *>(m_pluginsItemInterface);
     if (pluginsItemInterfaceV2) {
-        Dock::PluginFlags flags;
         flags = pluginsItemInterfaceV2->flags();
         if (pluginsItemInterfaceV2->pluginName() == "grand-search") {
             flags |= (Dock::PluginFlag)Attribute_ForceUnDock;
         }
-        return flags;
     } else {
         bool ok;
-        auto flags = m_pluginInstance->property("pluginFlags").toInt(&ok);
+        auto object = dynamic_cast<QObject*>(m_pluginsItemInterface);
+        if (object)
+            flags = (Dock::PluginFlag)object->property("pluginFlags").toInt(&ok);
         if (!ok) {
             qWarning() << "failed to pluginFlags toInt!";
-            return defaultPluginFlags;
         }
-        return flags;
     }
+
+    return flags;
 }
 
 QString WidgetPlugin::messageCallback(PluginsItemInterfaceV2 *pluginItem, const QString &msg)
@@ -399,7 +401,10 @@ QString WidgetPlugin::messageCallback(PluginsItemInterfaceV2 *pluginItem, const
         }
     } else {
         foreach (auto plugin, Plugin::EmbedPlugin::all()) {
-            Q_EMIT plugin->requestMessage(msg);
+            if (plugin->pluginId() == pluginItem->pluginName()) {
+                Q_EMIT plugin->requestMessage(msg);
+                break;
+            }
         }
     }
 
